<input type="text"
 id="{{ id }}"
 class="colorfield_field jscolor {% if class %}{{ class }}{% else %}form-control{% endif %}"
 name="{{ name }}"
 value="{% firstof value default '' %}"
 placeholder="{% firstof value default '' %}"
 data-jscolor="{hash:true,width:225,height:150,format:'{{ format }}',required:{% if required %}true{% else %}false{% endif %},paletteCols:4,paletteHeight:28{% if palette %},palette:{{ palette|safe }}{% endif %}}"
 {% if disabled %}disabled{% endif %}
 {% if required %}required{% endif %} />
